.. dav-tools documentation master file, created by
   sphinx-quickstart on Sun Jul 16 15:00:51 2023.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to dav-tools's documentation!
=====================================
Personal Python library to aid in software development.


Installation
============
``$ pip install dav-tools``


Usage
=====
``dav-tools`` contains a variety of diffent submodules, each with its own set of functionalities.

Importing is done in the form of ``from dav_tools import <submodule>`` since it usually doesn't make sense to import the whole library.


Contents
========

.. toctree::
   :maxdepth: 4


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
